| align | R Documentation |
These property functions modify or return the text alignment in a hf_line
object. Supported options are: 'left', 'right', 'center', and 'split'.
An alignment option of 'split' requires that two text elements are provided
in the titles/footnotes hf_line object. The first text element will
be aligned on the left and the second on the right.
align(x, ...)
align(x) <- value
set_align(x, value)
x |
|
... |
Additional arguments passed to method dispatch. |
value |
A string representing the alignment. |
For align(), the alignment of the supplied hf_line object.
For set_align() and `align<-`(), the modified object.
library(huxtable)
ht <- huxtable(
column1 = 1:5,
column2 = letters[1:5]
)
rtf <- rtf_doc(ht, list(hf_line("aTitle")))
pharmaRTF::align(rtf$titles[[1]])
# Returns "center"
pharmaRTF::align(rtf$titles[[1]]) <- "left"
# Sets alignment to 'left'
pharmaRTF::text(rtf$titles[[1]]) <- c("Left Text", "Right Text")
pharmaRTF::align(rtf$titles[[1]]) <- "split"
# When rtf is printed, "Left Text" will be left aligned, and "Right Text"
# will be right aligned. Both will appear on the same line in the document.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.