| bold | R Documentation |
These property functions modify or return the bold attribute of a
hf_line object.
bold(x, ...)
bold(x) <- value
set_bold(x, value)
x |
A |
... |
Additonal arguments passed to method dispatch |
value |
A logical vector to set the value of the bold attribute |
For bold(), the bold attribute of the supplied hf_line
object. For `bold<-`() and set_bold(), the modified object.
library(huxtable)
ht <- huxtable(
column1 = 1:5,
column2 = letters[1:5]
)
rtf <- rtf_doc(ht, list(hf_line("aTitle")))
pharmaRTF::bold(rtf$titles[[1]])
# Returns FALSE
pharmaRTF::bold(rtf$titles[[1]]) <- TRUE
# Sets bold to TRUE
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.