pharmaRTF-package: pharmaRTF

pharmaRTF-packageR Documentation

pharmaRTF

Description

Enhanced RTF wrapper written in R for use with existing R tables packages such as huxtable or GT. This package fills a gap where tables in certain packages can be written out to RTF, but cannot add certain metadata or features to the document that are required/expected in a report for a regulatory submission, such as multiple levels of titles and footnotes, making the document landscape, and controlling properties such as margins.

This package intends to provide a flexible and reliable framework to connect R to a pharmaceutical reporting workflow.

Future Plans

  • colors

  • graphs

Author(s)

Maintainer: Michael Stackhouse mike.stackhouse@atorusresearch.com (ORCID)

Authors:

Other contributors:

  • Atorus Research LLC [copyright holder]

See Also

Useful links:


pharmaRTF documentation built on Sept. 22, 2026, 5:10 p.m.