write_rtf: Write RTF document

View source: R/rtf-code-generators.R

write_rtfR Documentation

Write RTF document

Description

Writes the RTF document to a specified file.

Usage

write_rtf(doc, file = NULL)

Arguments

doc

The RTF document to be written.

file

A character string naming a file open for writing.

Value

File is written to the file provided by sinking the console output. No output is returned to the R environment.

Examples

## Create and write RTF document
ht <- huxtable::huxtable(
 column1 = 1:5,
 column2 = letters[1:5]
)
rtf <- rtf_doc(ht)

write_rtf(rtf, file=tempfile()) #writes a table with no header/footnotes to 'test.rtf'


pharmaRTF documentation built on Sept. 22, 2026, 5:10 p.m.