View source: R/rtf-code-generators.R
| write_rtf | R Documentation |
Writes the RTF document to a specified file.
write_rtf(doc, file = NULL)
doc |
The RTF document to be written. |
file |
A character string naming a file open for writing. |
File is written to the file provided by sinking the console output. No output is returned to the R environment.
## Create and write RTF document
ht <- huxtable::huxtable(
column1 = 1:5,
column2 = letters[1:5]
)
rtf <- rtf_doc(ht)
write_rtf(rtf, file=tempfile()) #writes a table with no header/footnotes to 'test.rtf'
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.